==> signalr_client-0.1.2.tar.gz: testapp/client/lib/tests/tests.dart <==
import 'package:client/tests/clientInvoke/clientInvokeMethodNoParametersNoReturnValue.dart';
import 'package:client/tests/clientInvoke/clientInvokeStreamRequest.dart';
import 'package:client/tests/clientInvoke/clientMethodNoParametersSimpleReturnValue.dart';
import 'package:client/tests/clientInvoke/clientMethodOneSimpleParameterNoReturnValue.dart';
import 'package:client/tests/clientInvoke/clientMethodOneSimpleParameterSimpleReturnValue.dart';
import 'package:client/tests/clientInvoke/serverInvokeMethodNoParametersNoReturnValue.dart';
import 'package:client/tests/clientInvoke/serverInvokeMethodSimpleParametersNoReturnValue.dart';
import 'package:client/tests/test.dart';
import 'package:client/views/pages/testsPageViewModel.dart';
import 'package:signalr_client/signalr_client.dart';

class Tests {
  // Properties
  List<Test> _items;

  // Methods
  List<Test> get items => _items;

  Tests(HubConnectionProvider connectionProvider, ILogger logger) {
    _items = List<Test>();

    _items.add(ClientMethodNoParametersNoReturnValue(connectionProvider, logger));
    _items.add(ClientMethodNoParametersSimpleReturnValue(connectionProvider, logger));
    _items.add(ClientMethodOneSimpleParameterNoReturnValue(connectionProvider, logger));
    _items.add(ClientMethodOneSimpleParameterSimpleReturnValue(connectionProvider, logger));

    _items.add(ServerInvokeMethodNoParametersNoReturnValue(connectionProvider, logger));
    _items.add(ServerInvokeMethodSimpleParametersNoReturnValue(connectionProvider, logger));

    _items.add(ClientInvokeStreamRequest(connectionProvider, logger));
  }
}

==> signalr_client-0.1.4.tar.gz: testapp/client/lib/tests/tests.dart <==
import 'package:client/tests/clientInvoke/clientInvokeMethodNoParametersNoReturnValue.dart';
import 'package:client/tests/clientInvoke/clientInvokeStreamRequest.dart';
import 'package:client/tests/clientInvoke/clientMethodNoParametersSimpleReturnValue.dart';
import 'package:client/tests/clientInvoke/clientMethodOneSimpleParameterNoReturnValue.dart';
import 'package:client/tests/clientInvoke/clientMethodOneSimpleParameterSimpleReturnValue.dart';
import 'package:client/tests/clientInvoke/serverInvokeMethodNoParametersNoReturnValue.dart';
import 'package:client/tests/clientInvoke/serverInvokeMethodSimpleParametersNoReturnValue.dart';
import 'package:client/tests/test.dart';
import 'package:client/views/pages/testsPageViewModel.dart';
import 'package:logging/logging.dart';

class Tests {
  // Properties
  List<Test> _items;

  // Methods
  List<Test> get items => _items;

  Tests(HubConnectionProvider connectionProvider, Logger logger) {
    _items = List<Test>();

    _items.add(ClientMethodNoParametersNoReturnValue(connectionProvider, logger));
    _items.add(ClientMethodNoParametersSimpleReturnValue(connectionProvider, logger));
    _items.add(ClientMethodOneSimpleParameterNoReturnValue(connectionProvider, logger));
    _items.add(ClientMethodOneSimpleParameterSimpleReturnValue(connectionProvider, logger));

    _items.add(ServerInvokeMethodNoParametersNoReturnValue(connectionProvider, logger));
    _items.add(ServerInvokeMethodSimpleParametersNoReturnValue(connectionProvider, logger));

    _items.add(ClientInvokeStreamRequest(connectionProvider, logger));
  }
}
